@@ -1,9 +1,11 @@
 import importlib
 from .cdn_client import CdnClient
+from .nas_client import NasClient
 from proxy_tools import proxy
 
 prod_mapper = {
-    'cdn': CdnClient
+    'cdn': CdnClient,
+    'nas': NasClient
 }
 
 
@@ -17,3 +19,8 @@ def get_current_client(prod):
 @proxy
 def cdn_client():
     return get_current_client('cdn')
+
+
+@proxy
+def nas_client():
+    return get_current_client('nas')
