@@ -4,12 +4,14 @@ from .clb_client import ClbClient
 from .cdn_client import CdnClient
 from .cfs_client import CfsClient
 from .vpc_client import VpcClient
+from .dns_client import DnsClient
 
 prod_mapper = {
     'clb': ClbClient,
     'cdn': CdnClient,
     'cfs': CfsClient,
     'vpc': VpcClient,
+    'dns': DnsClient
 }
 
 
@@ -38,3 +40,7 @@ def cfs_client():
 @proxy
 def vpc_client():
     return get_current_client('vpc')
+
+@proxy
+def dns_client():
+    return get_current_client('dns')
\ No newline at end of file
